==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ClusterCSIDriverBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterCSIDriverBuilder extends io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriverFluentImpl<io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriverBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriver,io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriverBuilder>{
  public ClusterCSIDriverBuilder() {
    this(false);
  }
  public ClusterCSIDriverBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterCSIDriver(), validationEnabled);
  }
  public ClusterCSIDriverBuilder(io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriverFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterCSIDriverBuilder(io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriverFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterCSIDriver(), validationEnabled);
  }
  public ClusterCSIDriverBuilder(io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriverFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriver instance) {
    this(fluent, instance, false);
  }
  public ClusterCSIDriverBuilder(io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriverFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriver instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterCSIDriverBuilder(io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriver instance) {
    this(instance,false);
  }
  public ClusterCSIDriverBuilder(io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriver instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriverFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.ClusterCSIDriver build() {
    ClusterCSIDriver buildable = new ClusterCSIDriver(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterCSIDriverBuilder that = (ClusterCSIDriverBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.6.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/ClusterCSIDriverBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterCSIDriverBuilder extends ClusterCSIDriverFluentImpl<ClusterCSIDriverBuilder> implements VisitableBuilder<ClusterCSIDriver,ClusterCSIDriverBuilder>{
  public ClusterCSIDriverBuilder() {
    this(false);
  }
  public ClusterCSIDriverBuilder(Boolean validationEnabled) {
    this(new ClusterCSIDriver(), validationEnabled);
  }
  public ClusterCSIDriverBuilder(ClusterCSIDriverFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterCSIDriverBuilder(ClusterCSIDriverFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterCSIDriver(), validationEnabled);
  }
  public ClusterCSIDriverBuilder(ClusterCSIDriverFluent<?> fluent,ClusterCSIDriver instance) {
    this(fluent, instance, false);
  }
  public ClusterCSIDriverBuilder(ClusterCSIDriverFluent<?> fluent,ClusterCSIDriver instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterCSIDriverBuilder(ClusterCSIDriver instance) {
    this(instance,false);
  }
  public ClusterCSIDriverBuilder(ClusterCSIDriver instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterCSIDriverFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterCSIDriver build() {
    ClusterCSIDriver buildable = new ClusterCSIDriver(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
